@@ -149,7 +149,9 @@ class AddTagAjaxFormWrapper(AddTagFormWrapper):
             saveButtonText: '%s',
             hyphenLabel: '%s'
         };
-        """ % (tx(self.form.label), tx(u"Remove"), tx(u"Are you sure you want to remove this tag?"), \
-               tx(u"Edit"), tx(u"Yes"), tx(u"No"), tx(u'Save'), tx(u"imagetags.hyphen"))
+        """ % (tx(self.form.label), tx(_(u"Remove")),
+               tx(_(u"Are you sure you want to remove this tag?")),
+               tx(_(u"Edit")), tx(_(u"Yes")), tx(_(u"No")), tx(_(u'Save')),
+               tx(_(u"imagetags.hyphen", default=u"-")))
         
 AddTagAjax = wrap_form(AddTagAjaxForm, __wrapper_class=AddTagAjaxFormWrapper)
