@@ -138,9 +138,9 @@ class ManageTags(BrowserView):
                     
         self._mark_interface(action='add')
         if new_tag:
-            message = _(u'Tag "${title}" added.', mapping={u'title': data['title']})
+            message = _(u"Tag '${title}' added.", mapping={u'title': data['title']})
         else:
-            message = _(u'Tag "${title}" updated.', mapping={u'title': data['title']})
+            message = _(u"Tag '${title}' updated.", mapping={u'title': data['title']})
 
         if not 'ajax' in data:
             IStatusMessage(self.request).addStatusMessage(message, type='info')
