@@ -393,7 +393,7 @@ ImageTags = {
         /* Reset the form to empty values (except for the "field"-named field)
          */
         var container = jQuery('#ajax-form');
-        container.find('input[type!=submit],select,textarea').not('input[name$=field:list],input[name$=ajax]').val('');
+        container.find('input[type!=submit],select,textarea').not('input[name$=field:list],input[name$=ajax],input[name$=decimal]').val('');
         container.find('.field-missing-value').removeClass('field-missing-value');
     },
 
